import { CronOptions } from '@aws-cdk/aws-events';
import { Construct } from '@aws-cdk/core';
/**
 * Props for the NightNight construct.
 *
 * @stability stable
 */
export interface NightyNightProps {
    /**
     * An option CronOptions to specify the time of day to stop the instance.
     *
     * @default {
     * day: '*',
     * hour: '4',
     * minute: '0'
     * }
     * @stability stable
     */
    readonly schedule?: CronOptions;
    /**
     * the instanceId of the EC2 instance you'd like stopped.
     *
     * @stability stable
     */
    readonly instanceId: string;
}
/**
 * A construct that will build a Lambda and a CloudWatch Rule (cron schedule) that will stop the given ec2 instance at the specified time.
 *
 * Typically used when you've got ec2 instances that you only need during business hours
 * and want to reduce the costs of.
 *
 * @stability stable
 */
export declare class NightyNight extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: NightyNightProps);
}
